Intbc <- function(exp, obs, target_grid, int_method, bc_method, ncores = 1) {

  require(CSTools)
 
  stopifnot(bc_method %in% c('sbc', 'cal', 'qm', 'simple_bias', 'calibration', 'quantile_mapping'))
  stopifnot(c('member','sdate') %in% names(dim(exp$data)))

  lonmin <- attr(exp$lon,"first_lon") # this should not be needed
  lonmax <- attr(exp$lon,"last_lon")
  latmin <- attr(exp$lat,"first_lat")
  latmax <- attr(exp$lat,"last_lat")
  exp_interpolated <- interpolation(exp = exp, target_grid = target_grid, method = int_method, 
                                    crop = c(lonmin, lonmax, latmin, latmax))

  # Interpolate obs to the same target grid to ensure the matching with exp coordinates
  obs_interpolated <- interpolation(exp = obs, target_grid = target_grid, method = int_method,
                                    crop = c(lonmin, lonmax, latmin, latmax))

  #.check_coords
  if (bc_method == 'sbc' | bc_method == 'simple_bias') {
    if (dim(obs_interpolated$data)['sdate'] == 1) {
      warning('**WARNING: Simple Bias Correction should not be used with 
              only one observation. Returning NA. ')
    }
    res <- BiasCorrection(exp = exp_interpolated$data, 
                          obs = obs_interpolated$data) 
  } 
  else if (bc_method == 'cal' | bc_method == 'calibration') {
    if (dim(exp_interpolated$data)['member'] == 1) {
      stop('**ERROR: Calibration must not be used with
           only one ensemble member.')
    }
    res <- Calibration(exp = exp_interpolated$data, obs = obs_interpolated$data, 
                       cal.method = 'mse_min', ncores = ncores)
  }
  else if (bc_method == 'qm' | bc_method == 'quantile_mapping') {
    res <- QuantileMapping(exp = exp_interpolated$data, obs = obs_interpolated$data, 
                           sample_dims = 'sdate', method = 'QUANT', ncores = ncores)
  }

  # Create an s2dv_cube object
  res_s2dv <- suppressWarnings(s2dv_cube(data = res, lon = exp_interpolated$lon, lat = exp_interpolated$lat))

  return(res_s2dv)
}




