
library(CSTools)
library(startR)
library(s2dv)
source('/esarchive/scratch/jramon/GitLab_jramon/downscaling/R/functions.R')

plotpath <- '/esarchive/scratch/jramon/downscaling/plots'
target_grid <- '/esarchive/recon/ecmwf/era5/daily/tasmax-r1440x721cds/tasmax_201702.nc'

lonmin <- -22
lonmax <- 45
latmin <- 27
latmax <- 72

#obs <- startR::Start(dat = '/esarchive/recon/ecmwf/era5/daily/$var$/$var$_201702.nc',
#                     var = 'tasmax', lon = 'all', lat = 'all', time = indices(1:10), 
#                     synonims = list(var = c('var','variable'),lon = c('lon', 'longitude'), lat = c('lat', 'latitude')),
#                     return_vars = list(lat = 'dat', lon = 'dat'),
#                     num_procs = 1, retrieve = TRUE)

#exp <- startR::Start(dat = '/esarchive/exp/ecmwf/system5c3s/daily/$var$/$var$_20170201.nc',
#                     var = 'tasmax', lon = 'all', lat = 'all', time = indices(1:10), member = indices(1),
#                     synonims = list(var = c('var','variable'),lon = c('lon', 'longitude'), lat = c('lat', 'latitude'), member = c('member','ensemble')),
#                     return_vars = list(lat = 'dat', lon = 'dat'),
#                     num_procs = 1, retrieve = TRUE)

#lat_obs <- as.numeric(attr(obs,'Variables')$dat$lat)
#lon_obs <- as.numeric(attr(obs,'Variables')$dat$lon)
#lat_exp <- as.numeric(attr(exp,'Variables')$dat$lat)
#lon_exp <- as.numeric(attr(exp,'Variables')$dat$lon)

obs <- CST_Load(var = 'tasmax',
                obs = 'era5',
                sdates = c('20170201','20170301','20170401','20170501','20170601'),
                leadtimemax = 1,
                latmin = latmin, latmax = latmax, lonmin = lonmin, lonmax = lonmax,
                output = 'lonlat')
obs$data <- drop(obs$data)

exp <- CST_Load(var = 'tasmax',
                exp = 'system5c3s',
                nmember = 3,
                sdates = c('20170201','20170301','20170401','20170501','20170601'),
                leadtimemax = 1,
                latmin = latmin, latmax = latmax, lonmin = lonmin, lonmax = lonmax,
                output = 'lonlat')

#ind rdm ha de ser o bé un vector o bé un array amb una dimensió anomenada 'sdate'
ind_rdm <- array(NA, dim = c('sdate' = 5,'vars' = 2))
ind_rdm[,1] <- rnorm(n=5,mean=0,sd=1)
ind_rdm[,2] <- rnorm(n=5,mean=0,sd=1)

int_method <- 'bil'
lr_methods <- c('basic', 'large-scale', '4nn')

for (i in seq(lr_methods)) {

  if (lr_methods[i] == 'large-scale') {
    predictors <- ind_rdm
  } else  {
    predictors <- NULL
  }
  downscaled <- Intlr(exp = exp, obs = obs, target_grid = target_grid, lr_method = lr_methods[i],
                      int_method = int_method, predictors = predictors, loocv = TRUE, ncores = 4)
  lats <- downscaled$lat
  lons <- downscaled$lon
  data <- downscaled$data
  s2dv::PlotEquiMap(var = data[1,,,1,1,1], lat = lats, lon = lons, filled.continents = FALSE,
                    toptitle = paste0(int_method, ' ', lr_methods[i]), 
                    fileout = file.path(plotpath, paste0(int_method, ' ', lr_methods[i],'-lr.png')))
}



