library(CSTools)
library(startR)
library(s2dv)
source('/esarchive/scratch/jramon/GitLab_jramon/downscaling/functions.R')

lonmin <- -22
lonmax <- 45
latmin <- 27
latmax <- 72

target_grid <- '/esarchive/recon/ecmwf/era5/daily/tasmax/tasmax_201702.nc'

obs <- CST_Load(var = 'tasmax',
                obs = 'era5',
                sdates = '20170201',
                leadtimemax = 1,
                latmin = latmin, latmax = latmax, lonmin = lonmin, lonmax = lonmax, 
                output = 'lonlat')

exp <- CST_Load(var = 'tasmax',
                exp = 'system5c3s',
                nmember = 1,
                sdates = '20170201',
                leadtimemax = 1,
                latmin = latmin, latmax = latmax, lonmin = lonmin, lonmax = lonmax, 
                output = 'lonlat') 

lon_exp <- exp$lon
lat_exp <- exp$lat
lon_obs <- obs$lon
lat_obs <- obs$lat

exp_con <- Interpolation(exp = exp, target_grid = target_grid, method = 'con', crop = c(lonmin,lonmax,latmin,latmax))
lat_con <- exp_con$lats
lon_con <- exp_con$lons
exp_con <- exp_con$data_array
exp_bil <- Interpolation(exp = exp, target_grid = target_grid, method = 'bil', crop = c(lonmin,lonmax,latmin,latmax))
lat_bil <- exp_bil$lats
lon_bil <- exp_bil$lons
exp_bil <- exp_bil$data_array
exp_bic <- Interpolation(exp = exp, target_grid = target_grid, method = 'bic', crop = c(lonmin,lonmax,latmin,latmax))
lat_bic <- exp_bic$lats
lon_bic <- exp_bic$lons
exp_bic <- exp_bic$data_array
exp_nn <- Interpolation(exp = exp, target_grid = target_grid, method = 'nn', crop = c(lonmin,lonmax,latmin,latmax))
lat_nn <- exp_nn$lats
lon_nn <- exp_nn$lons
exp_nn <- exp_nn$data_array
exp_con2 <- Interpolation(exp = exp, target_grid = target_grid, method = 'con2', crop = c(lonmin,lonmax,latmin,latmax))
lat_con2 <- exp_con2$lats
lon_con2 <- exp_con2$lons
exp_con2 <- exp_con2$data_array

s2dv::PlotEquiMap(var = obs, lat = lat_obs, lon = lon_obs, filled.continents = FALSE, toptitle = 'Observations')
s2dv::PlotEquiMap(var = exp$data, lat = lat_exp, lon = lon_exp, filled.continents = FALSE, toptitle = 'Predictions')
s2dv::PlotEquiMap(var = exp_con, lat = lat_con, lon = lon_con, filled.continents = FALSE, toptitle = 'Conservative')
s2dv::PlotEquiMap(var = exp_bil, lat = lat_bil, lon = lon_bil, filled.continents = FALSE, toptitle = 'Bilinear')
s2dv::PlotEquiMap(var = exp_bic, lat = lat_bic, lon = lon_bic, filled.continents = FALSE, toptitle = 'Bicubic')
s2dv::PlotEquiMap(var = exp_nn, lat = lat_nn, lon = lon_nn, filled.continents = FALSE, toptitle = 'Nearest neighbour')
s2dv::PlotEquiMap(var = exp_con2, lat = lat_con2, lon = lon_con2, filled.continents = FALSE, toptitle = '2nd order conservative')

